==> haskell-summoner-tui-2.0.1.1-742-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-HaJCQ8599XfEE8Tq819EgN
key:                  summoner-tui-2.0.1.1-HaJCQ8599XfEE8Tq819EgN
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  2f8a156077d4e6391b5dcdab7e1a6331
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-HaJCQ8599XfEE8Tq819EgN
depends:
    base-4.18.2.1 relude-1.2.2.2-32n808Z7KD86XTUuYaQJid
    brick-0.71.1-BB1br4uc1DV7K8gQTvMbB
    colourista-0.1.0.2-J1xkje1pgaxLw08GswM2K0 directory-1.3.8.5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    summoner-2.0.1.1-7OAIPrpnVdgGHR25wSlzug
    validation-selective-0.2.0.0-3bAaDEcZOe43DQlEVmr5ec
    vty-5.39-BJo6QdyGYf81rIuO8T8QMN

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-tui-2.0.1.1-743-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-68IkX1cnTaXHWnjtKR5CRv
key:                  summoner-tui-2.0.1.1-68IkX1cnTaXHWnjtKR5CRv
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  32d9855117dec693143f61b2494ea4f7
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-68IkX1cnTaXHWnjtKR5CRv
depends:
    base-4.18.2.1 relude-1.2.2.2-4xszWfaRZ9A9ngo7Mj8r9K
    brick-0.71.1-1NN5A0GRpkS1u7Ql1uSNWB
    colourista-0.1.0.2-H317eOxsS0vLSaP5vW7Z2A directory-1.3.8.5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    summoner-2.0.1.1-AMpKgHbYNfZCN2T7HeTkUE
    validation-selective-0.2.0.0-GAVv1iBW9h6BnssFde9oPQ
    vty-5.39-CXCawhWqYCIA5G1k8qF9p

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
